@@ -1,14 +1,12 @@
 """Joseki."""
 from . import accessor
-from ._version import _version as __version__
-from .core import Identifier  # pyflakes.ignore
-from .core import make  # pyflakes.ignore
+from .__version__ import __version__ as __version__
+from .core import make
 from .units import ureg as unit_registry
 
 
 __all__ = [
     "accessor",
-    "Identifier",
     "make",
     "unit_registry",
     "__version__",
